On some BCM5301x ARM devices, user space still needs to control some
system GPIO pins for which no driver exists. This is a lot easier to do
with a predictable GPIO base.

Signed-off-by: Felix Fietkau <[email protected]>
---
 drivers/bcma/driver_gpio.c | 19 ++++++++++---------
 1 file changed, 10 insertions(+), 9 deletions(-)

diff --git a/drivers/bcma/driver_gpio.c b/drivers/bcma/driver_gpio.c
index 74ccb02..9b8d9bf 100644
--- a/drivers/bcma/driver_gpio.c
+++ b/drivers/bcma/driver_gpio.c
@@ -235,16 +235,17 @@ int bcma_gpio_init(struct bcma_drv_cc *cc)
        }
 
        /*
         * On MIPS we register GPIO devices (LEDs, buttons) using absolute GPIO
         * pin numbers. We don't have Device Tree there and we can't really use
         * relative (per chip) numbers.
         * So let's use predictable base for BCM47XX and "random" for all other.
chip)
+        * GPIO numbers.
+        * On some ARM devices, user space may want to access some system GPIO
+        * pins directly, which is easier to do with a predictable GPIO base.
         */
-#if IS_BUILTIN(CONFIG_BCM47XX)
-       chip->base              = bus->num * BCMA_GPIO_MAX_PINS;
-#else
-       chip->base              = -1;
-#endif
+       if (IS_BUILTIN(CONFIG_BCM47XX) ||
+           cc->core->bus->hosttype == BCMA_HOSTTYPE_SOC)
+               chip->base              = bus->num * BCMA_GPIO_MAX_PINS;
+       else
+               chip->base              = -1;
 
        err = bcma_gpio_irq_domain_init(cc);
        if (err)
@@ -235,16 +235,17 @@ int bcma_gpio_init(struct bcma_drv_cc *cc)
 
        /*
-        * On MIPS we register GPIO devices (LEDs, buttons) using absolute GPIO
-        * pin numbers. We don't have Device Tree there and we can't really use
-        * relative (per chip) numbers.
-        * So let's use predictable base for BCM47XX and "random" for all other.
+        * Register SoC GPIO devices with absolute GPIO pin base.
+        * On MIPS, we don't have Device Tree and we can't use relative (per 
chip)
-- 
2.2.2

--
To unsubscribe from this list: send the line "unsubscribe linux-wireless" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to